{----------------------------------------------------}
{ Andreis LCARS-Components 1.0 for Delphi (2, 3), 4 }
{ Copyright (c) 1999 Andrei Scheibner                }
{ http://www.htwm.de/~ascheibn                       }
{ ascheibn@htwm.de                                   }
{----------------------------------------------------}
{These Components are Freeware, you can distribute it,}
{you can improve it (because these are my first Delphi}
{components this may be necessary), but I would appreciate}
{it, if my name appears somewhere in your improvements}

unit LCARSPanel;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs;


type
  TCaptionPosition = (cpCenter, cpTopLeft, cpTopRight, cpBottomRight, cpBottomLeft);
  TLCARSPanel = class(TGraphicControl)
  private
   FBack : TBitmap;
   FBackColor : TColor;
   FCaption : TCaption;
   FCaptionWidth : integer;
   FCaptionHeight : integer;
   FCaptionPosX : integer;
   FCaptionPosY : integer;
   FCaptionMarginX : integer;
   FCaptionMarginY : integer;
   FCaptionPosition : TCaptionPosition;
   procedure SetCaption(value : TCaption);
   procedure SetCaptionPosition(value : TCaptionPosition);
   procedure SetCaptionMarginX(value : integer);
   procedure SetCaptionMarginY(value : integer);
  protected
   procedure Paint; override;
  public
   constructor Create(AOwner : TComponent) ; override;
   destructor Destroy; override;
  published
   property Parent;
   property Width default 129;
   property Height default 41;
   property Visible default true;
   property Enabled default true;
   property Font;
   property ParentFont default true;
   property CaptionPosition : TCaptionPosition read FCaptionPosition
    write SetCaptionPosition default cpCenter;
   property Caption : TCaption read FCaption
    write SetCaption;
   property CaptionMarginX : integer read FCaptionMarginX
    write SetCaptionMarginX default 2;
   property CaptionMarginY : integer read FCaptionMarginY
    write SetCaptionMarginY default 0;
   property Color default clyellow;
   property OnClick;
   property OnDblClick;
   property OnMouseDown;
   property OnMouseUp;
   property OnMouseMove;
   property OnDragDrop;
   property OnDragOver;
   property OnEndDrag;
  end;

procedure Register;

implementation

constructor TLCARSPanel.Create(AOwner : TComponent);
begin
 inherited Create(AOwner);
 Width := 80;
 Height := 40;
 Color := clyellow;
 FBackColor := clBlack;
 Visible := true;
 CaptionPosition := cpCenter;
 FBack := TBitmap.Create;
 CaptionMarginX := 2;
 CaptionMarginY := 0;
 ParentFont := true;
end;

destructor TLCARSPanel.Destroy;
begin
 FBack.Free;
 inherited Destroy;
end;

procedure TLCARSPanel.Paint;
var VisibleRect, BackRect : TRect;
begin
 FBack.Canvas.Font.Assign(Font);
 FBack.Width := Width;
 FBack.Height := Height;
 if Parent <> nil then
  with Parent do
   FBackColor := Color;
 FCaptionWidth := FBack.Canvas.TextWidth(FCaption);
 FCaptionHeight := FBack.Canvas.TextHeight(FCaption);
 FBack.Canvas.Brush.Color := FBackColor;
 FBack.Canvas.Pen.Color := FBackColor;
 FBack.Canvas.Rectangle(0, 0, FBack.Width, FBack.Height);
 FBack.Canvas.Brush.Color := Color;
 FBack.Canvas.Pen.Color := Color;
 FBack.Canvas.Rectangle(0,0, FBack.width, FBack.height);
 FBack.Canvas.FloodFill(FBack.width div 2,FBack.height div 2,
                        FBack.Canvas.Pixels[FBack.width div 2,FBack.height div 2],
                        fssurface);
 case FCaptionPosition of
  cpCenter :
   begin
    FCaptionPosX := (FBack.Width div 2) - (FCaptionWidth div 2);
    FCaptionPosY := (FBack.Height div 2) - (FCaptionHeight div 2);
   end;
  cpTopLeft :
   begin
    FCaptionPosX := CaptionMarginX;
    FCaptionPosY := CaptionMarginY;
   end;
  cpTopRight :
   begin
    FCaptionPosX := FBack.Width - CaptionMarginX - FCaptionWidth;
    FCaptionPosY := CaptionMarginY;
   end;
  cpBottomRight :
   begin
    FCaptionPosX := FBack.Width - CaptionMarginX - FCaptionWidth;
    FCaptionPosY := FBack.Height - CaptionMarginY - FCaptionHeight;
   end;
  cpBottomLeft :
   begin
    FCaptionPosX := CaptionMarginX;
    FCaptionPosY := FBack.Height - CaptionMarginY - FCaptionHeight;
   end;
 end;
 FBack.Canvas.TextOut(FCaptionPosX, FCaptionPosY, FCaption);
 VisibleRect := Rect(0, 0, Width, Height);
 BackRect := Rect(0, 0, FBack.Width, Fback.Height);
 Canvas.CopyRect(VisibleRect, FBack.Canvas, BackRect);
end;

procedure TLCARSPanel.SetCaption(value : TCaption);
begin
 if FCaption <> value then
  begin
   FCaption := value;
   Invalidate;
  end;
end;

procedure TLCARSPanel.SetCaptionPosition(value : TCaptionPosition);
begin
 if FCaptionPosition <> value then
  begin
   FCaptionPosition := value;
   Invalidate;
  end;
end;

procedure TLCARSPanel.SetCaptionMarginX(value : integer);
begin
 if FCaptionMarginX <> value then
  begin
   FCaptionMarginX := value;
   Invalidate;
  end;
end;

procedure TLCARSPanel.SetCaptionMarginY(value : integer);
begin
 if FCaptionMarginY <> value then
  begin
   FCaptionMarginY := value;
   Invalidate;
  end;
end;

procedure Register;
begin
  RegisterComponents('LCARS-Comps', [TLCARSPanel]);
end;

end.
